==> mesian-v0.1.1.tar.bz2: mesian-v0.1.1/www-data/lib/Page.php <==
<?

class Page {

	var $page_total;
	var $page_current;
	var $directory;

	var $item_total_num;

	var $DB;

	var $SQL_GET_TOTAL_ITEM =
		"select SQL_CACHE count(no) as num from item_%s where directory_num = '%s'";

	function Page ($directory, $page_current="") {
		$this->Template = new Template;

		$this->DB = new MySQLdb;

		$this->directory = $directory;
		$this->get_page_total();

		if ($page_current) $this->set($page_current);
	}

	function set ($page_current) {
		if ($page_current < 0) {
			$this->page_current = "0";
		} else {
			$this->page_current = $page_current;

			if ($this->page_current > $this->page_total) {
				$this->page_current = $this->page_total - 1;
			}
		}
	}

	function get_page_total () {

		$o = $this->DB->fetch_one(sprintf($this->SQL_GET_TOTAL_ITEM,
			$_SESSION["config_id"], $this->directory));

		$this->item_total_num = $o["num"];

		if ($o["num"] < $_SESSION["config_pageLimit"]) {
			$this->page_total = "1";
		} else {
			$a = intval($o["num"] / $_SESSION["config_pageLimit"]);
			$b = intval($o["num"] % $_SESSION["config_pageLimit"]);

			if ($b == "0") {
				$this->page_total = $a;
			} else {
				$this->page_total = $a + 1;
			}
		}
	}

	function print_list ($page_current="") {
		global $global, $string;

		if ($page_current) $this->set($page_current);

		// page numbering.
		if ($this->page_total > 1) {
			for ($i = 0; $i < $this->page_total; $i++) {
				$one["num"] = $i;

				if ($i == $this->page_current) {
					$one["page_num"] =
						sprintf("<span class=\"label2\">%s</span>", $i);
				} else {
					$one["page_num"] =
						sprintf("<a href=\"%s/mail?no=%s&pg=%s\">%s</a>",
							$_SESSION["user_www_url"], $_SESSION["user_directory"],$i, $i);
				}

				$main["content"] .=
					$this->Template->generate("/module/item/template/page_list_one", $one);
			}
		}

		$prv = $this->page_current - 1;
		$fwd = $this->page_current + 1;

		if ($prv < 0) $prv = "0";
		if ($fwd > $this->page_total) $fwd = $this->page_total;

		if ($this->page_current < 1) {
			$main["prv"] = sprintf("<img class=\"mesian\" src=\"%s/previous.png\">",
				$_SESSION["user_www_url"] . "/module/item/image");
		} else {
			$main["prv"] =
				sprintf("<a href=\"%s/mail?no=%s&pg=%s\"
					><img class=\"mesian\" src=\"%s/previous.png\"></a>",
					$_SESSION["user_www_url"], $_SESSION["user_directory"], $prv, $_SESSION["user_www_url"] .
					"/module/item/image");
		}

		if ($fwd == $this->page_total) {
			$main["fwd"] = sprintf("<img class=\"mesian\" src=\"%s/forward.png\">", $_SESSION["user_www_url"] .
				"/module/item/image");
		} else {
			$main["fwd"] =
				sprintf("<a href=\"%s/mail?no=%s&pg=%s\"
					><img class=\"mesian\" src=\"%s/forward.png\"></a>",
					$_SESSION["user_www_url"], $_SESSION["user_directory"], $fwd, $_SESSION["user_www_url"] .
					"/module/item/image");
		}

		$ret = $this->Template->generate("/module/item/template/page_list", $main);

		return $ret;
	}

}

class Page_Forum {

	var $page_total;
	var $page_current;
	var $directory;

	var $item_total_num;

	var $DB;

	var $id;

	var $SQL_GET_TOTAL_ITEM =
		"select SQL_CACHE count(no) as num from forum_%s";

	function Page_Forum ($id, $page_current="") {

		$this->id = $id;

		$this->Template = new Template;

		$this->DB = new MySQLdb;

		$this->get_page_total();

		if ($page_current) $this->set($page_current);
	}

	function set ($page_current) {
		if ($page_current < 0) {
			$this->page_current = "0";
		} else {
			$this->page_current = $page_current;

			if ($this->page_current > $this->page_total) {
				$this->page_current = $this->page_total - 1;
			}
		}
	}

	function get_page_total () {

		$o = $this->DB->fetch_one(sprintf($this->SQL_GET_TOTAL_ITEM, $this->id));

		$this->item_total_num = $o["num"];

		if ($o["num"] < $_SESSION["config_pageLimit"]) {
			$this->page_total = "1";
		} else {
			$a = intval($o["num"] / $_SESSION["config_pageLimit"]);
			$b = intval($o["num"] % $_SESSION["config_pageLimit"]);

			if ($b == "0") {
				$this->page_total = $a;
			} else {
				$this->page_total = $a + 1;
			}
		}
	}

	function print_list ($page_current="") {
		global $global, $string;

		if ($page_current) $this->set($page_current);

		// page numbering.
		if ($this->page_total > 1) {
			for ($i = 0; $i < $this->page_total; $i++) {
				$one["num"] = $i;

				if ($i == $this->page_current) {
					$one["page_num"] =
						sprintf("<span class=\"label2\">%s</span>", $i);
				} else {
					$one["page_num"] =
						sprintf(
							"<a href=\"%s/forum?mode=list&pg=%s&id=%s\">%s</a>",
							$_SESSION["user_forum_url"],$i, $this->id, $i);
				}

				$main["content"] .=
					$this->Template->generate("/module/forum/template/page_list_one", $one);
			}
		}

		$prv = $this->page_current - 1;
		$fwd = $this->page_current + 1;

		if ($prv < 0) $prv = "0";
		if ($fwd > $this->page_total) $fwd = $this->page_total;

		if ($this->page_current < 1) {
			$main["prv"] =
				sprintf("<img class=\"mesian\" src=\"%s/module/item/image/previous-30-off.png\">%s",
				$_SESSION["user_forum_url"], $string["item25"]);
		} else {
			$main["prv"] =
				sprintf("<a href=\"%s/forum?mode=list&pg=%s&id=%s\"
					><img class=\"mesian\" src=\"%s/module/item/image/previous-30-off.png\">%s</a>",
					$_SESSION["user_forum_url"], $prv, $this->id, $_SESSION["user_forum_url"], $string["item25"]);
		}

		if ($fwd == $this->page_total) {
			$main["fwd"] =
				sprintf("%s<img class=\"mesian\" src=\"%s/module/item/image/forward-30-off.png\">",
				$string["item26"], $_SESSION["user_forum_url"]);
		} else {
			$main["fwd"] =
				sprintf("<a href=\"%s/forum?mode=list&pg=%s&id=%s\"
					>%s<img class=\"mesian\" src=\"%s/module/item/image/forward-30-off.png\"></a>",
					$_SESSION["user_forum_url"], $fwd, $this->id, $string["item26"], $_SESSION["user_forum_url"]);
		}

		$ret = $this->Template->generate("/module/forum/template/page_list", $main);

		return $ret;
	}

}

/*
Description
-----------

Author
------
 Spike^ekipS <spike@spikeekips.net>

Changelog
---------

Usage
-----

*/

?>

==> mesian-v0.1.2.tar.bz2: mesian-v0.1.2/www-data/lib/Page.php <==
<?

class Page {

	var $page_total;
	var $page_current;
	var $directory;

	var $item_total_num;

	var $DB;

	var $SQL_GET_TOTAL_ITEM =
		"select SQL_CACHE count(no) as num from item_%s where directory_num = '%s'";

	function Page ($directory, $page_current="") {
		$this->Template = new Template;

		$this->DB = new MySQLdb;

		$this->directory = $directory;
		$this->get_page_total();

		if ($page_current) $this->set($page_current);
	}

	function set ($page_current) {
		if ($page_current < 0) {
			$this->page_current = "0";
		} else {
			$this->page_current = $page_current;

			if ($this->page_current > $this->page_total) {
				$this->page_current = $this->page_total - 1;
			}
		}
	}

	function get_page_total () {

		$o = $this->DB->fetch_one(sprintf($this->SQL_GET_TOTAL_ITEM,
			$_SESSION["config_id"], $this->directory));

		$this->item_total_num = $o["num"];

		if ($o["num"] < $_SESSION["config_pageLimit"]) {
			$this->page_total = "1";
		} else {
			$a = intval($o["num"] / $_SESSION["config_pageLimit"]);
			$b = intval($o["num"] % $_SESSION["config_pageLimit"]);

			if ($b == "0") {
				$this->page_total = $a;
			} else {
				$this->page_total = $a + 1;
			}
		}
	}

	function print_list ($page_current="") {
		global $global, $string;

		if ($page_current) $this->set($page_current);

		// page numbering.
		if ($this->page_total > 1) {
			for ($i = 0; $i < $this->page_total; $i++) {
				$one["num"] = $i;

				if ($i == $this->page_current) {
					$one["page_num"] =
						sprintf("<span class=\"mesian_label2\">%s</span>", $i + 1);
				} else {
					$one["page_num"] =
						sprintf("<a class=\"mesian\" href=\"%s/mail?no=%s&pg=%s\">%s</a>",
							$_SESSION["user_www_url"], $_SESSION["user_directory"],$i, $i + 1);
				}

				$main["content"] .=
					$this->Template->generate("/module/item/template/page_list_one", $one);
			}
		}

		$prv = $this->page_current - 1;
		$fwd = $this->page_current + 1;

		if ($prv < 0) $prv = "0";
		if ($fwd > $this->page_total) $fwd = $this->page_total;

		if ($this->page_current < 1) {
			$main["prv"] = sprintf("<img class=\"mesian\" src=\"%s/previous.png\">",
				$_SESSION["user_www_url"] . "/module/item/image");
		} else {
			$main["prv"] =
				sprintf("<a class=\"mesian\" href=\"%s/mail?no=%s&pg=%s\"
					><img class=\"mesian\" src=\"%s/previous.png\"></a>",
					$_SESSION["user_www_url"], $_SESSION["user_directory"],
					$prv, $_SESSION["user_www_url"] .
					"/module/item/image");
		}

		if ($fwd == $this->page_total) {
			$main["fwd"] =
				sprintf("<img class=\"mesian\" src=\"%s/forward.png\">",
				$_SESSION["user_www_url"] . "/module/item/image");
		} else {
			$main["fwd"] =
				sprintf("<a class=\"mesian\" href=\"%s/mail?no=%s&pg=%s\"
					><img class=\"mesian\" src=\"%s/forward.png\"></a>",
					$_SESSION["user_www_url"], $_SESSION["user_directory"],
					$fwd, $_SESSION["user_www_url"] .
					"/module/item/image");
		}

		$ret = $this->Template->generate("/module/item/template/page_list", $main);

		return $ret;
	}

}

class Page_card {

	var $page_total;
	var $page_current;

	var $group_no;
	var $card_total_num;

	var $DB;

	function Page_card ($group_no, $total_item_number="0", $page_current="") {
		$this->Template = new Template;

		$this->DB = new MySQLdb;

		$this->group_no = $group_no;
		$this->get_page_total($total_item_number);

		if ($page_current) $this->set($page_current);
	}

	function set ($page_current) {
		if ($page_current < 0) {
			$this->page_current = "0";
		} else {
			$this->page_current = $page_current;

			if ($this->page_current > $this->page_total) {
				$this->page_current = $this->page_total - 1;
			}
		}
	}

	function get_page_total ($total_item_number="") {

		$this->card_total_num = $total_item_number;

		if ($this->card_total_num < $_SESSION["config_pageLimit"]) {
			$this->page_total = "1";
		} else {
			$a = intval($this->card_total_num / $_SESSION["config_pageLimit"]);
			$b = intval($this->card_total_num % $_SESSION["config_pageLimit"]);

			if ($b == "0") {
				$this->page_total = $a;
			} else {
				$this->page_total = $a + 1;
			}
		}
	}

	function print_list ($page_current="") {
		global $global, $string;

		if ($page_current) $this->set($page_current);

		// page numbering.
		if ($this->page_total > 1) {
			for ($i = 0; $i < $this->page_total; $i++) {
				$one["num"] = $i;

				if ($i == $this->page_current) {
					$one["page_num"] =
						sprintf("<span class=\"mesian_label2\">%s</span>", $i + 1);
				} else {
					$one["page_num"] =
						sprintf("<a class=\"mesian\"
							href=\"%s/mail?mode=card&no=%s&pg=%s\">%s</a>",
							$_SESSION["user_www_url"], $_SESSION["user_group_no"], $i, $i + 1);
				}

				$main["content"] .=
					$this->Template->generate("/module/item/template/page_list_one", $one);
			}
		}

		$prv = $this->page_current - 1;
		$fwd = $this->page_current + 1;

		if ($prv < 0) $prv = "0";
		if ($fwd > $this->page_total) $fwd = $this->page_total;

		if ($this->page_current < 1) {
			$main["prv"] = sprintf("<img class=\"mesian\" src=\"%s/previous.png\">",
				$_SESSION["user_www_url"] . "/module/item/image");
		} else {
			$main["prv"] =
				sprintf("<a class=\"mesian\" href=\"%s/mail?mode=card&no=%s&pg=%s\"
					><img class=\"mesian\" src=\"%s/previous.png\"></a>",
					$_SESSION["user_www_url"], $_SESSION["user_group_no"],
					$prv, $_SESSION["user_www_url"] . "/module/item/image");
		}

		if ($fwd == $this->page_total) {
			$main["fwd"] = sprintf("<img class=\"mesian\" src=\"%s/forward.png\">",
				$_SESSION["user_www_url"] . "/module/item/image");
		} else {
			$main["fwd"] =
				sprintf("<a class=\"mesian\" href=\"%s/mail?mode=card&no=%s&pg=%s\"
					><img class=\"mesian\" src=\"%s/forward.png\"></a>",
					$_SESSION["user_www_url"], $_SESSION["user_group_no"],
					$fwd, $_SESSION["user_www_url"] . "/module/item/image");
		}

		$ret = $this->Template->generate("/module/item/template/page_list", $main);

		return $ret;
	}

}

class Page_Forum {

	var $page_total;
	var $page_current;
	var $directory;

	var $item_total_num;

	var $DB;

	var $id;

	var $SQL_GET_TOTAL_ITEM =
		"select SQL_CACHE count(no) as num from forum_%s";

	function Page_Forum ($id, $page_current="") {

		$this->id = $id;

		$this->Template = new Template;

		$this->DB = new MySQLdb;

		$this->get_page_total();

		if ($page_current) $this->set($page_current);
	}

	function set ($page_current) {
		if ($page_current < 0) {
			$this->page_current = "0";
		} else {
			$this->page_current = $page_current;

			if ($this->page_current > $this->page_total) {
				$this->page_current = $this->page_total - 1;
			}
		}
	}

	function get_page_total () {

		$o = $this->DB->fetch_one(sprintf($this->SQL_GET_TOTAL_ITEM, $this->id));

		$this->item_total_num = $o["num"];

		if ($o["num"] < $_SESSION["config_pageLimit"]) {
			$this->page_total = "1";
		} else {
			$a = intval($o["num"] / $_SESSION["config_pageLimit"]);
			$b = intval($o["num"] % $_SESSION["config_pageLimit"]);

			if ($b == "0") {
				$this->page_total = $a;
			} else {
				$this->page_total = $a + 1;
			}
		}
	}

	function print_list ($page_current="") {
		global $global, $string;

		if ($page_current) $this->set($page_current);

		// page numbering.
		if ($this->page_total > 1) {
			for ($i = 0; $i < $this->page_total; $i++) {
				$one["num"] = $i;

				if ($i == $this->page_current) {
					$one["page_num"] =
						sprintf("<span class=\"mesian_label2\">%s</span>", $i);
				} else {
					$one["page_num"] =
						sprintf(
							"<a class=\"mesian\" href=\"%s/forum?mode=list&pg=%s&id=%s\">%s</a>",
							$_SESSION["user_forum_url"],$i, $this->id, $i);
				}

				$main["content"] .=
					$this->Template->generate("/module/forum/template/page_list_one", $one);
			}
		}

		$prv = $this->page_current - 1;
		$fwd = $this->page_current + 1;

		if ($prv < 0) $prv = "0";
		if ($fwd > $this->page_total) $fwd = $this->page_total;

		if ($this->page_current < 1) {
			$main["prv"] =
				sprintf("<img class=\"mesian\"
					src=\"%s/module/item/image/previous-30-off.png\">%s",
				$_SESSION["user_forum_url"], $string["item25"]);
		} else {
			$main["prv"] =
				sprintf("<a class=\"mesian\" href=\"%s/forum?mode=list&pg=%s&id=%s\"
					><img class=\"mesian\"
					src=\"%s/module/item/image/previous-30-off.png\">%s</a>",
					$_SESSION["user_forum_url"], $prv, $this->id, $_SESSION["user_forum_url"], $string["item25"]);
		}

		if ($fwd == $this->page_total) {
			$main["fwd"] =
				sprintf("%s<img class=\"mesian\" src=\"%s/module/item/image/forward-30-off.png\">",
				$string["item26"], $_SESSION["user_forum_url"]);
		} else {
			$main["fwd"] =
				sprintf("<a class=\"mesian\" href=\"%s/forum?mode=list&pg=%s&id=%s\"
					>%s<img class=\"mesian\"
					src=\"%s/module/item/image/forward-30-off.png\"></a>",
					$_SESSION["user_forum_url"], $fwd,
					$this->id, $string["item26"], $_SESSION["user_forum_url"]);
		}

		$ret = $this->Template->generate("/module/forum/template/page_list", $main);

		return $ret;
	}

}

/*
Description
-----------

Author
------
 Spike^ekipS <spike@spikeekips.net>

Changelog
---------

Usage
-----

*/

?>
